package de.hft.stuttgart.citydoctor2.connect.edge;

// im alten CD:
//
public class CppPolygonHealing extends CppHealing {

	// ----- native methods
	// create and release stored C++ polygon check object
	private native long createCppPolygonHealing(long ptrToCppFeature) throws OutOfMemoryError;

	private native void disposeCppPolygonHealing(long ptrToCppFeature) throws NativePointerCastException;

	// healing
	private native long healPlanarity(long ptrToCppFeature, int[] polyIds)
			throws NativeException, IllegalArgumentException;
    
    private native long healSolidNotClosed(long ptrToCppFeature)
			throws NativeException, IllegalArgumentException;
    

	public CppPolygonHealing(CppFeature feature) {
		super(feature);
	}

	/**
	 * Creates an C++ object to use the native solid check methods.
	 * 
	 * @throws IllegalStateException Thrown if the encapsulated "long-Pointer" isn't
	 *                               0
	 * @throws OutOfMemoryError      If there is no more memory on the native side
	 * 
	 * @see {@link disposeCppObject}
	 * @see de.hft.stuttgart.citydoctor.connect.edGe.CppReferenceHandlingBase#createCppObject()
	 */
	public void createCppObject() throws IllegalStateException, OutOfMemoryError {
		if (0L != ptrToCppObject) {
			throw new IllegalStateException("Can't create new C++ object, there is allready one!");
		}
		// Maybe an exception is thrown and there should be no crap in ptrToCppObject
		long tmpPointer = createCppPolygonHealing(feature.ptrToCppObject);
		ptrToCppObject = tmpPointer;

	}

	@Override
	public void disposeCppObject() throws NativePointerCastException {
		if (0L != ptrToCppObject) {
			disposeCppPolygonHealing(this.ptrToCppObject);
			ptrToCppObject = 0L;
		}
	}

	public CppHealResult healPlanarity(int[] polyIds) throws NativeException, IllegalArgumentException {
		checkNullPointer();
		return new CppHealResult( healPlanarity( this.feature.ptrToCppObject, polyIds ));
	}

   
    public CppHealResult healSolidNotClosed() throws NativeException, IllegalArgumentException{
        checkNullPointer();
        return new CppHealResult( healSolidNotClosed( this.feature.ptrToCppObject ));
    }
}
